/****************************************************************************
** Meta object code from reading C++ file 'foreigntoplevellist.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../protocols/foreigntoplevellist.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'foreigntoplevellist.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19ForeignToplevelListE_t {};
} // unnamed namespace

template <> constexpr inline auto ForeignToplevelList::qt_create_metaobjectdata<qt_meta_tag_ZN19ForeignToplevelListE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ForeignToplevelList",
        "toplevelAdded",
        "",
        "ForeignToplevelHandle*",
        "handle",
        "finished"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'toplevelAdded'
        QtMocHelpers::SignalData<void(ForeignToplevelHandle *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'finished'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ForeignToplevelList, qt_meta_tag_ZN19ForeignToplevelListE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ForeignToplevelList::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandClientExtensionTemplate<ForeignToplevelList>::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19ForeignToplevelListE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19ForeignToplevelListE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19ForeignToplevelListE_t>.metaTypes,
    nullptr
} };

void ForeignToplevelList::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ForeignToplevelList *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->toplevelAdded((*reinterpret_cast<std::add_pointer_t<ForeignToplevelHandle*>>(_a[1]))); break;
        case 1: _t->finished(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< ForeignToplevelHandle* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ForeignToplevelList::*)(ForeignToplevelHandle * )>(_a, &ForeignToplevelList::toplevelAdded, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ForeignToplevelList::*)()>(_a, &ForeignToplevelList::finished, 1))
            return;
    }
}

const QMetaObject *ForeignToplevelList::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ForeignToplevelList::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19ForeignToplevelListE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QtWayland::ext_foreign_toplevel_list_v1"))
        return static_cast< QtWayland::ext_foreign_toplevel_list_v1*>(this);
    return QWaylandClientExtensionTemplate<ForeignToplevelList>::qt_metacast(_clname);
}

int ForeignToplevelList::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandClientExtensionTemplate<ForeignToplevelList>::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void ForeignToplevelList::toplevelAdded(ForeignToplevelHandle * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ForeignToplevelList::finished()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
namespace {
struct qt_meta_tag_ZN21ForeignToplevelHandleE_t {};
} // unnamed namespace

template <> constexpr inline auto ForeignToplevelHandle::qt_create_metaobjectdata<qt_meta_tag_ZN21ForeignToplevelHandleE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ForeignToplevelHandle",
        "closed",
        "",
        "done",
        "titleChanged",
        "title",
        "appIdChanged",
        "app_id",
        "identifierChanged",
        "identifier"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'closed'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'done'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'titleChanged'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'appIdChanged'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'identifierChanged'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ForeignToplevelHandle, qt_meta_tag_ZN21ForeignToplevelHandleE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ForeignToplevelHandle::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ForeignToplevelHandleE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ForeignToplevelHandleE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21ForeignToplevelHandleE_t>.metaTypes,
    nullptr
} };

void ForeignToplevelHandle::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ForeignToplevelHandle *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->closed(); break;
        case 1: _t->done(); break;
        case 2: _t->titleChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->appIdChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->identifierChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ForeignToplevelHandle::*)()>(_a, &ForeignToplevelHandle::closed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ForeignToplevelHandle::*)()>(_a, &ForeignToplevelHandle::done, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ForeignToplevelHandle::*)(const QString & )>(_a, &ForeignToplevelHandle::titleChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ForeignToplevelHandle::*)(const QString & )>(_a, &ForeignToplevelHandle::appIdChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ForeignToplevelHandle::*)(const QString & )>(_a, &ForeignToplevelHandle::identifierChanged, 4))
            return;
    }
}

const QMetaObject *ForeignToplevelHandle::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ForeignToplevelHandle::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ForeignToplevelHandleE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QtWayland::ext_foreign_toplevel_handle_v1"))
        return static_cast< QtWayland::ext_foreign_toplevel_handle_v1*>(this);
    return QObject::qt_metacast(_clname);
}

int ForeignToplevelHandle::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void ForeignToplevelHandle::closed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ForeignToplevelHandle::done()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ForeignToplevelHandle::titleChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ForeignToplevelHandle::appIdChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void ForeignToplevelHandle::identifierChanged(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
