// SPDX-FileCopyrightText: 2025-2026 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#pragma once

#include <QDebug>
#include <QLoggingCategory>

Q_DECLARE_LOGGING_CATEGORY(PORTAL_COMMON)
Q_DECLARE_LOGGING_CATEGORY(SCREESHOT)
Q_DECLARE_LOGGING_CATEGORY(PIPEWIRE)
Q_DECLARE_LOGGING_CATEGORY(SCREENCAST)
Q_DECLARE_LOGGING_CATEGORY(WALLPAPER)
