/****************************************************************************
** Meta object code from reading C++ file 'screencopy.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../protocols/screencopy.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'screencopy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN15ScreenCopyFrameE_t {};
} // unnamed namespace

template <> constexpr inline auto ScreenCopyFrame::qt_create_metaobjectdata<qt_meta_tag_ZN15ScreenCopyFrameE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ScreenCopyFrame",
        "buffer",
        "",
        "uint32_t",
        "format",
        "width",
        "height",
        "stride",
        "frameFlags",
        "flags",
        "ready",
        "tv_sec_hi",
        "tv_sec_lo",
        "tv_nsec",
        "failed",
        "damage",
        "x",
        "y",
        "linuxDmabuf",
        "bufferDone"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'buffer'
        QtMocHelpers::SignalData<void(uint32_t, uint32_t, uint32_t, uint32_t)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 3, 5 }, { 0x80000000 | 3, 6 }, { 0x80000000 | 3, 7 },
        }}),
        // Signal 'frameFlags'
        QtMocHelpers::SignalData<void(uint32_t)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 9 },
        }}),
        // Signal 'ready'
        QtMocHelpers::SignalData<void(uint32_t, uint32_t, uint32_t)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 11 }, { 0x80000000 | 3, 12 }, { 0x80000000 | 3, 13 },
        }}),
        // Signal 'failed'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'damage'
        QtMocHelpers::SignalData<void(uint32_t, uint32_t, uint32_t, uint32_t)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 16 }, { 0x80000000 | 3, 17 }, { 0x80000000 | 3, 5 }, { 0x80000000 | 3, 6 },
        }}),
        // Signal 'linuxDmabuf'
        QtMocHelpers::SignalData<void(uint32_t, uint32_t, uint32_t)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 3, 5 }, { 0x80000000 | 3, 6 },
        }}),
        // Signal 'bufferDone'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ScreenCopyFrame, qt_meta_tag_ZN15ScreenCopyFrameE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ScreenCopyFrame::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ScreenCopyFrameE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ScreenCopyFrameE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15ScreenCopyFrameE_t>.metaTypes,
    nullptr
} };

void ScreenCopyFrame::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ScreenCopyFrame *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->buffer((*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[4]))); break;
        case 1: _t->frameFlags((*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[1]))); break;
        case 2: _t->ready((*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[3]))); break;
        case 3: _t->failed(); break;
        case 4: _t->damage((*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[4]))); break;
        case 5: _t->linuxDmabuf((*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[3]))); break;
        case 6: _t->bufferDone(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ScreenCopyFrame::*)(uint32_t , uint32_t , uint32_t , uint32_t )>(_a, &ScreenCopyFrame::buffer, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ScreenCopyFrame::*)(uint32_t )>(_a, &ScreenCopyFrame::frameFlags, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ScreenCopyFrame::*)(uint32_t , uint32_t , uint32_t )>(_a, &ScreenCopyFrame::ready, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ScreenCopyFrame::*)()>(_a, &ScreenCopyFrame::failed, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ScreenCopyFrame::*)(uint32_t , uint32_t , uint32_t , uint32_t )>(_a, &ScreenCopyFrame::damage, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ScreenCopyFrame::*)(uint32_t , uint32_t , uint32_t )>(_a, &ScreenCopyFrame::linuxDmabuf, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ScreenCopyFrame::*)()>(_a, &ScreenCopyFrame::bufferDone, 6))
            return;
    }
}

const QMetaObject *ScreenCopyFrame::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ScreenCopyFrame::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15ScreenCopyFrameE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QtWayland::zwlr_screencopy_frame_v1"))
        return static_cast< QtWayland::zwlr_screencopy_frame_v1*>(this);
    return QObject::qt_metacast(_clname);
}

int ScreenCopyFrame::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void ScreenCopyFrame::buffer(uint32_t _t1, uint32_t _t2, uint32_t _t3, uint32_t _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 1
void ScreenCopyFrame::frameFlags(uint32_t _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ScreenCopyFrame::ready(uint32_t _t1, uint32_t _t2, uint32_t _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}

// SIGNAL 3
void ScreenCopyFrame::failed()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ScreenCopyFrame::damage(uint32_t _t1, uint32_t _t2, uint32_t _t3, uint32_t _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 5
void ScreenCopyFrame::linuxDmabuf(uint32_t _t1, uint32_t _t2, uint32_t _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2, _t3);
}

// SIGNAL 6
void ScreenCopyFrame::bufferDone()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
namespace {
struct qt_meta_tag_ZN17ScreenCopyManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto ScreenCopyManager::qt_create_metaobjectdata<qt_meta_tag_ZN17ScreenCopyManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ScreenCopyManager"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ScreenCopyManager, qt_meta_tag_ZN17ScreenCopyManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ScreenCopyManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandClientExtensionTemplate<ScreenCopyManager>::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17ScreenCopyManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17ScreenCopyManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17ScreenCopyManagerE_t>.metaTypes,
    nullptr
} };

void ScreenCopyManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ScreenCopyManager *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *ScreenCopyManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ScreenCopyManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17ScreenCopyManagerE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QtWayland::zwlr_screencopy_manager_v1"))
        return static_cast< QtWayland::zwlr_screencopy_manager_v1*>(this);
    return QWaylandClientExtensionTemplate<ScreenCopyManager>::qt_metacast(_clname);
}

int ScreenCopyManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandClientExtensionTemplate<ScreenCopyManager>::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
