// SPDX-FileCopyrightText: 2025-2026 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: LGPL-3.0-or-later

#include "loggings.h"

Q_LOGGING_CATEGORY(PORTAL_COMMON, "dde.portal.Common", QtWarningMsg)
Q_LOGGING_CATEGORY(SCREESHOT, "dde.portal.ScreenShot", QtWarningMsg)
Q_LOGGING_CATEGORY(PIPEWIRE, "dde.portal.ScreenCast.PipeWire", QtWarningMsg)
Q_LOGGING_CATEGORY(SCREENCAST, "dde.portal.ScreenCast", QtWarningMsg)
Q_LOGGING_CATEGORY(WALLPAPER, "dde.portal.Wallpaper", QtWarningMsg)
