/****************************************************************************
** Meta object code from reading C++ file 'abstractpipewirestream.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../abstractpipewirestream.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'abstractpipewirestream.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN22AbstractPipeWireStreamE_t {};
} // unnamed namespace

template <> constexpr inline auto AbstractPipeWireStream::qt_create_metaobjectdata<qt_meta_tag_ZN22AbstractPipeWireStreamE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AbstractPipeWireStream",
        "ready",
        "",
        "uint32_t",
        "nodeId",
        "created",
        "nodeid",
        "failed",
        "error",
        "closed",
        "handleCaptureSessionBufferSizeChanged",
        "width",
        "height",
        "handleCaptureSessionShmFormatChanged",
        "format",
        "handleCaptureSessionDmabufDeviceChanged",
        "wl_array*",
        "device",
        "handleCaptureSessionDmabufFormatChanged",
        "modifiers",
        "handleCaptureSessionDone",
        "handleCaptureSessionStopped",
        "handleFrameTransform",
        "transform",
        "handleFrameDamage",
        "int32_t",
        "x",
        "y",
        "handleFramePresentationTime",
        "tv_sec_hi",
        "tv_sec_lo",
        "tv_nsec",
        "handleFrameReady",
        "handleFrameFailed",
        "reason",
        "handleTimeOut"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ready'
        QtMocHelpers::SignalData<void(uint32_t)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'created'
        QtMocHelpers::SignalData<void(quint32)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 6 },
        }}),
        // Signal 'failed'
        QtMocHelpers::SignalData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Signal 'closed'
        QtMocHelpers::SignalData<void(uint32_t)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'handleCaptureSessionBufferSizeChanged'
        QtMocHelpers::SlotData<void(uint32_t, uint32_t)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 11 }, { 0x80000000 | 3, 12 },
        }}),
        // Slot 'handleCaptureSessionShmFormatChanged'
        QtMocHelpers::SlotData<void(uint32_t)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 14 },
        }}),
        // Slot 'handleCaptureSessionDmabufDeviceChanged'
        QtMocHelpers::SlotData<void(wl_array *)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 },
        }}),
        // Slot 'handleCaptureSessionDmabufFormatChanged'
        QtMocHelpers::SlotData<void(uint32_t, wl_array *)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 14 }, { 0x80000000 | 16, 19 },
        }}),
        // Slot 'handleCaptureSessionDone'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleCaptureSessionStopped'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleFrameTransform'
        QtMocHelpers::SlotData<void(uint32_t)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 23 },
        }}),
        // Slot 'handleFrameDamage'
        QtMocHelpers::SlotData<void(int32_t, int32_t, int32_t, int32_t)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 26 }, { 0x80000000 | 25, 27 }, { 0x80000000 | 25, 11 }, { 0x80000000 | 25, 12 },
        }}),
        // Slot 'handleFramePresentationTime'
        QtMocHelpers::SlotData<void(uint32_t, uint32_t, uint32_t)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 29 }, { 0x80000000 | 3, 30 }, { 0x80000000 | 3, 31 },
        }}),
        // Slot 'handleFrameReady'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'handleFrameFailed'
        QtMocHelpers::SlotData<void(uint32_t)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 34 },
        }}),
        // Slot 'handleTimeOut'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AbstractPipeWireStream, qt_meta_tag_ZN22AbstractPipeWireStreamE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AbstractPipeWireStream::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22AbstractPipeWireStreamE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22AbstractPipeWireStreamE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22AbstractPipeWireStreamE_t>.metaTypes,
    nullptr
} };

void AbstractPipeWireStream::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractPipeWireStream *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ready((*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[1]))); break;
        case 1: _t->created((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1]))); break;
        case 2: _t->failed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->closed((*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[1]))); break;
        case 4: _t->handleCaptureSessionBufferSizeChanged((*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[2]))); break;
        case 5: _t->handleCaptureSessionShmFormatChanged((*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[1]))); break;
        case 6: _t->handleCaptureSessionDmabufDeviceChanged((*reinterpret_cast<std::add_pointer_t<wl_array*>>(_a[1]))); break;
        case 7: _t->handleCaptureSessionDmabufFormatChanged((*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<wl_array*>>(_a[2]))); break;
        case 8: _t->handleCaptureSessionDone(); break;
        case 9: _t->handleCaptureSessionStopped(); break;
        case 10: _t->handleFrameTransform((*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[1]))); break;
        case 11: _t->handleFrameDamage((*reinterpret_cast<std::add_pointer_t<int32_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int32_t>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int32_t>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int32_t>>(_a[4]))); break;
        case 12: _t->handleFramePresentationTime((*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[3]))); break;
        case 13: _t->handleFrameReady(); break;
        case 14: _t->handleFrameFailed((*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[1]))); break;
        case 15: _t->handleTimeOut(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AbstractPipeWireStream::*)(uint32_t )>(_a, &AbstractPipeWireStream::ready, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPipeWireStream::*)(quint32 )>(_a, &AbstractPipeWireStream::created, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPipeWireStream::*)(const QString & )>(_a, &AbstractPipeWireStream::failed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPipeWireStream::*)(uint32_t )>(_a, &AbstractPipeWireStream::closed, 3))
            return;
    }
}

const QMetaObject *AbstractPipeWireStream::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AbstractPipeWireStream::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22AbstractPipeWireStreamE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AbstractPipeWireStream::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void AbstractPipeWireStream::ready(uint32_t _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void AbstractPipeWireStream::created(quint32 _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void AbstractPipeWireStream::failed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void AbstractPipeWireStream::closed(uint32_t _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
