/****************************************************************************
** Meta object code from reading C++ file 'imagecopycapture.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../protocols/imagecopycapture.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'imagecopycapture.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN23ImageCopyCaptureManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto ImageCopyCaptureManager::qt_create_metaobjectdata<qt_meta_tag_ZN23ImageCopyCaptureManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ImageCopyCaptureManager"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ImageCopyCaptureManager, qt_meta_tag_ZN23ImageCopyCaptureManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ImageCopyCaptureManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandClientExtensionTemplate<ImageCopyCaptureManager>::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23ImageCopyCaptureManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23ImageCopyCaptureManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23ImageCopyCaptureManagerE_t>.metaTypes,
    nullptr
} };

void ImageCopyCaptureManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ImageCopyCaptureManager *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *ImageCopyCaptureManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ImageCopyCaptureManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23ImageCopyCaptureManagerE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QtWayland::ext_image_copy_capture_manager_v1"))
        return static_cast< QtWayland::ext_image_copy_capture_manager_v1*>(this);
    return QWaylandClientExtensionTemplate<ImageCopyCaptureManager>::qt_metacast(_clname);
}

int ImageCopyCaptureManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandClientExtensionTemplate<ImageCopyCaptureManager>::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN23ImageCopyCaptureSessionE_t {};
} // unnamed namespace

template <> constexpr inline auto ImageCopyCaptureSession::qt_create_metaobjectdata<qt_meta_tag_ZN23ImageCopyCaptureSessionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ImageCopyCaptureSession",
        "bufferSizeChanged",
        "",
        "uint32_t",
        "width",
        "height",
        "shmFormatChanged",
        "format",
        "dmabufDeviceChanged",
        "wl_array*",
        "device",
        "dmabufFormatChanged",
        "modifiers",
        "done",
        "stopped"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'bufferSizeChanged'
        QtMocHelpers::SignalData<void(uint32_t, uint32_t)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 3, 5 },
        }}),
        // Signal 'shmFormatChanged'
        QtMocHelpers::SignalData<void(uint32_t)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 7 },
        }}),
        // Signal 'dmabufDeviceChanged'
        QtMocHelpers::SignalData<void(wl_array *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'dmabufFormatChanged'
        QtMocHelpers::SignalData<void(uint32_t, wl_array *)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 7 }, { 0x80000000 | 9, 12 },
        }}),
        // Signal 'done'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stopped'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ImageCopyCaptureSession, qt_meta_tag_ZN23ImageCopyCaptureSessionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ImageCopyCaptureSession::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23ImageCopyCaptureSessionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23ImageCopyCaptureSessionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23ImageCopyCaptureSessionE_t>.metaTypes,
    nullptr
} };

void ImageCopyCaptureSession::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ImageCopyCaptureSession *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->bufferSizeChanged((*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[2]))); break;
        case 1: _t->shmFormatChanged((*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[1]))); break;
        case 2: _t->dmabufDeviceChanged((*reinterpret_cast<std::add_pointer_t<wl_array*>>(_a[1]))); break;
        case 3: _t->dmabufFormatChanged((*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<wl_array*>>(_a[2]))); break;
        case 4: _t->done(); break;
        case 5: _t->stopped(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ImageCopyCaptureSession::*)(uint32_t , uint32_t )>(_a, &ImageCopyCaptureSession::bufferSizeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImageCopyCaptureSession::*)(uint32_t )>(_a, &ImageCopyCaptureSession::shmFormatChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImageCopyCaptureSession::*)(wl_array * )>(_a, &ImageCopyCaptureSession::dmabufDeviceChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImageCopyCaptureSession::*)(uint32_t , wl_array * )>(_a, &ImageCopyCaptureSession::dmabufFormatChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImageCopyCaptureSession::*)()>(_a, &ImageCopyCaptureSession::done, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImageCopyCaptureSession::*)()>(_a, &ImageCopyCaptureSession::stopped, 5))
            return;
    }
}

const QMetaObject *ImageCopyCaptureSession::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ImageCopyCaptureSession::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23ImageCopyCaptureSessionE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QtWayland::ext_image_copy_capture_session_v1"))
        return static_cast< QtWayland::ext_image_copy_capture_session_v1*>(this);
    return QObject::qt_metacast(_clname);
}

int ImageCopyCaptureSession::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void ImageCopyCaptureSession::bufferSizeChanged(uint32_t _t1, uint32_t _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void ImageCopyCaptureSession::shmFormatChanged(uint32_t _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ImageCopyCaptureSession::dmabufDeviceChanged(wl_array * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ImageCopyCaptureSession::dmabufFormatChanged(uint32_t _t1, wl_array * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void ImageCopyCaptureSession::done()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ImageCopyCaptureSession::stopped()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
namespace {
struct qt_meta_tag_ZN21ImageCopyCaptureFrameE_t {};
} // unnamed namespace

template <> constexpr inline auto ImageCopyCaptureFrame::qt_create_metaobjectdata<qt_meta_tag_ZN21ImageCopyCaptureFrameE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ImageCopyCaptureFrame",
        "transformChanged",
        "",
        "uint32_t",
        "transform",
        "damaged",
        "int32_t",
        "x",
        "y",
        "width",
        "height",
        "presentationTimeChanged",
        "tv_sec_hi",
        "tv_sec_lo",
        "tv_nsec",
        "ready",
        "failed",
        "reason"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'transformChanged'
        QtMocHelpers::SignalData<void(uint32_t)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'damaged'
        QtMocHelpers::SignalData<void(int32_t, int32_t, int32_t, int32_t)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 6, 8 }, { 0x80000000 | 6, 9 }, { 0x80000000 | 6, 10 },
        }}),
        // Signal 'presentationTimeChanged'
        QtMocHelpers::SignalData<void(uint32_t, uint32_t, uint32_t)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 12 }, { 0x80000000 | 3, 13 }, { 0x80000000 | 3, 14 },
        }}),
        // Signal 'ready'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'failed'
        QtMocHelpers::SignalData<void(uint32_t)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 17 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ImageCopyCaptureFrame, qt_meta_tag_ZN21ImageCopyCaptureFrameE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ImageCopyCaptureFrame::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ImageCopyCaptureFrameE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ImageCopyCaptureFrameE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21ImageCopyCaptureFrameE_t>.metaTypes,
    nullptr
} };

void ImageCopyCaptureFrame::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ImageCopyCaptureFrame *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->transformChanged((*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[1]))); break;
        case 1: _t->damaged((*reinterpret_cast<std::add_pointer_t<int32_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int32_t>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int32_t>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int32_t>>(_a[4]))); break;
        case 2: _t->presentationTimeChanged((*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[3]))); break;
        case 3: _t->ready(); break;
        case 4: _t->failed((*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ImageCopyCaptureFrame::*)(uint32_t )>(_a, &ImageCopyCaptureFrame::transformChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImageCopyCaptureFrame::*)(int32_t , int32_t , int32_t , int32_t )>(_a, &ImageCopyCaptureFrame::damaged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImageCopyCaptureFrame::*)(uint32_t , uint32_t , uint32_t )>(_a, &ImageCopyCaptureFrame::presentationTimeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImageCopyCaptureFrame::*)()>(_a, &ImageCopyCaptureFrame::ready, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImageCopyCaptureFrame::*)(uint32_t )>(_a, &ImageCopyCaptureFrame::failed, 4))
            return;
    }
}

const QMetaObject *ImageCopyCaptureFrame::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ImageCopyCaptureFrame::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21ImageCopyCaptureFrameE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QtWayland::ext_image_copy_capture_frame_v1"))
        return static_cast< QtWayland::ext_image_copy_capture_frame_v1*>(this);
    return QObject::qt_metacast(_clname);
}

int ImageCopyCaptureFrame::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void ImageCopyCaptureFrame::transformChanged(uint32_t _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ImageCopyCaptureFrame::damaged(int32_t _t1, int32_t _t2, int32_t _t3, int32_t _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 2
void ImageCopyCaptureFrame::presentationTimeChanged(uint32_t _t1, uint32_t _t2, uint32_t _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}

// SIGNAL 3
void ImageCopyCaptureFrame::ready()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ImageCopyCaptureFrame::failed(uint32_t _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN29ImageCopyCaptureCursorSessionE_t {};
} // unnamed namespace

template <> constexpr inline auto ImageCopyCaptureCursorSession::qt_create_metaobjectdata<qt_meta_tag_ZN29ImageCopyCaptureCursorSessionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ImageCopyCaptureCursorSession",
        "enter",
        "",
        "leave",
        "positionChanged",
        "int32_t",
        "x",
        "y",
        "hotspotChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'enter'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'leave'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'positionChanged'
        QtMocHelpers::SignalData<void(int32_t, int32_t)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 5, 7 },
        }}),
        // Signal 'hotspotChanged'
        QtMocHelpers::SignalData<void(int32_t, int32_t)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 }, { 0x80000000 | 5, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ImageCopyCaptureCursorSession, qt_meta_tag_ZN29ImageCopyCaptureCursorSessionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ImageCopyCaptureCursorSession::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29ImageCopyCaptureCursorSessionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29ImageCopyCaptureCursorSessionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN29ImageCopyCaptureCursorSessionE_t>.metaTypes,
    nullptr
} };

void ImageCopyCaptureCursorSession::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ImageCopyCaptureCursorSession *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->enter(); break;
        case 1: _t->leave(); break;
        case 2: _t->positionChanged((*reinterpret_cast<std::add_pointer_t<int32_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int32_t>>(_a[2]))); break;
        case 3: _t->hotspotChanged((*reinterpret_cast<std::add_pointer_t<int32_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int32_t>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ImageCopyCaptureCursorSession::*)()>(_a, &ImageCopyCaptureCursorSession::enter, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImageCopyCaptureCursorSession::*)()>(_a, &ImageCopyCaptureCursorSession::leave, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImageCopyCaptureCursorSession::*)(int32_t , int32_t )>(_a, &ImageCopyCaptureCursorSession::positionChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ImageCopyCaptureCursorSession::*)(int32_t , int32_t )>(_a, &ImageCopyCaptureCursorSession::hotspotChanged, 3))
            return;
    }
}

const QMetaObject *ImageCopyCaptureCursorSession::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ImageCopyCaptureCursorSession::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29ImageCopyCaptureCursorSessionE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QtWayland::ext_image_copy_capture_cursor_session_v1"))
        return static_cast< QtWayland::ext_image_copy_capture_cursor_session_v1*>(this);
    return QObject::qt_metacast(_clname);
}

int ImageCopyCaptureCursorSession::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void ImageCopyCaptureCursorSession::enter()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ImageCopyCaptureCursorSession::leave()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ImageCopyCaptureCursorSession::positionChanged(int32_t _t1, int32_t _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void ImageCopyCaptureCursorSession::hotspotChanged(int32_t _t1, int32_t _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}
QT_WARNING_POP
