// This file is autogenerated. Changes will be overwritten.
#include "VNU7RW3YIC/moc_wallpaper.cpp"
#include "EWIEGA46WW/moc_abstractpipewirestream.cpp"
#include "EWIEGA46WW/moc_dbushelpers.cpp"
#include "EWIEGA46WW/moc_outputpipewirestream.cpp"
#include "EWIEGA46WW/moc_pipewirecore.cpp"
#include "EWIEGA46WW/moc_portalcommon.cpp"
#include "EWIEGA46WW/moc_portalwaylandcontext.cpp"
#include "QEXRLBDUJQ/moc_foreigntoplevellist.cpp"
#include "QEXRLBDUJQ/moc_imagecapturesource.cpp"
#include "QEXRLBDUJQ/moc_imagecopycapture.cpp"
#include "QEXRLBDUJQ/moc_linuxdmabufer.cpp"
#include "QEXRLBDUJQ/moc_screencopy.cpp"
#include "QEXRLBDUJQ/moc_shmbuffer.cpp"
#include "QEXRLBDUJQ/moc_treelandcapture.cpp"
#include "QEXRLBDUJQ/moc_wallpapermanagerclient.cpp"
#include "EWIEGA46WW/moc_remotedesktopsession.cpp"
#include "EWIEGA46WW/moc_request2.cpp"
#include "EWIEGA46WW/moc_screencastchooser.cpp"
#include "EWIEGA46WW/moc_screencastcontext.cpp"
#include "EWIEGA46WW/moc_screencastportal.cpp"
#include "EWIEGA46WW/moc_screencastsession.cpp"
#include "EWIEGA46WW/moc_screenlistmodel.cpp"
#include "EWIEGA46WW/moc_screenshotportal.cpp"
#include "EWIEGA46WW/moc_session.cpp"
#include "EWIEGA46WW/moc_toplevelmodel.cpp"
#include "EWIEGA46WW/moc_toplevelpipewirestream.cpp"
#include "EWIEGA46WW/moc_treelandintegration.cpp"
