/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<portalcommon.h>)
#  include <portalcommon.h>
#endif
#if __has_include(<screenlistmodel.h>)
#  include <screenlistmodel.h>
#endif
#if __has_include(<toplevelmodel.h>)
#  include <toplevelmodel.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_screencast()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<PortalCommon>("screencast", 1);
    qmlRegisterEnum<PortalCommon::SourceType>("PortalCommon::SourceType");
    qmlRegisterEnum<PortalCommon::CursorModes>("PortalCommon::CursorModes");
    qmlRegisterEnum<PortalCommon::PersistMode>("PortalCommon::PersistMode");
    qmlRegisterEnum<PortalCommon::BufferType>("PortalCommon::BufferType");
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    qmlRegisterTypesAndRevisions<ScreenListModel>("screencast", 1);
    qmlRegisterTypesAndRevisions<ToplevelListModel>("screencast", 1);
    QT_WARNING_POP
    qmlRegisterModule("screencast", 1, 0);
}

static const QQmlModuleRegistration screencastRegistration("screencast", qml_register_types_screencast);
