/****************************************************************************
** Meta object code from reading C++ file 'portalcommon.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../portalcommon.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'portalcommon.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12PortalCommonE_t {};
} // unnamed namespace

template <> constexpr inline auto PortalCommon::qt_create_metaobjectdata<qt_meta_tag_ZN12PortalCommonE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PortalCommon",
        "QML.Element",
        "auto",
        "SourceType",
        "Any",
        "Monitor",
        "Window",
        "CursorModes",
        "Hidden",
        "Embedded",
        "Metadata",
        "PersistMode",
        "NoPersist",
        "PersistWhileRunning",
        "PersistUntilRevoked",
        "BufferType",
        "SHM",
        "DMABUF"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'SourceType'
        QtMocHelpers::EnumData<enum SourceType>(3, 3, QMC::EnumFlags{}).add({
            {    4, SourceType::Any },
            {    5, SourceType::Monitor },
            {    6, SourceType::Window },
        }),
        // enum 'CursorModes'
        QtMocHelpers::EnumData<enum CursorModes>(7, 7, QMC::EnumFlags{}).add({
            {    8, CursorModes::Hidden },
            {    9, CursorModes::Embedded },
            {   10, CursorModes::Metadata },
        }),
        // enum 'PersistMode'
        QtMocHelpers::EnumData<enum PersistMode>(11, 11, QMC::EnumFlags{}).add({
            {   12, PersistMode::NoPersist },
            {   13, PersistMode::PersistWhileRunning },
            {   14, PersistMode::PersistUntilRevoked },
        }),
        // enum 'BufferType'
        QtMocHelpers::EnumData<enum BufferType>(15, 15, QMC::EnumFlags{}).add({
            {   16, BufferType::SHM },
            {   17, BufferType::DMABUF },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<PortalCommon, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PortalCommon::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12PortalCommonE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12PortalCommonE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12PortalCommonE_t>.metaTypes,
    nullptr
} };

void PortalCommon::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PortalCommon *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *PortalCommon::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PortalCommon::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12PortalCommonE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int PortalCommon::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
