/****************************************************************************
** Meta object code from reading C++ file 'wallpapermanagerclient.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../protocols/wallpapermanagerclient.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'wallpapermanagerclient.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN26TreelandWallpaperManagerV1E_t {};
} // unnamed namespace

template <> constexpr inline auto TreelandWallpaperManagerV1::qt_create_metaobjectdata<qt_meta_tag_ZN26TreelandWallpaperManagerV1E_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TreelandWallpaperManagerV1"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TreelandWallpaperManagerV1, qt_meta_tag_ZN26TreelandWallpaperManagerV1E_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TreelandWallpaperManagerV1::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandClientExtensionTemplate<TreelandWallpaperManagerV1>::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26TreelandWallpaperManagerV1E_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26TreelandWallpaperManagerV1E_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN26TreelandWallpaperManagerV1E_t>.metaTypes,
    nullptr
} };

void TreelandWallpaperManagerV1::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TreelandWallpaperManagerV1 *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *TreelandWallpaperManagerV1::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TreelandWallpaperManagerV1::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN26TreelandWallpaperManagerV1E_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QtWayland::treeland_wallpaper_manager_v1"))
        return static_cast< QtWayland::treeland_wallpaper_manager_v1*>(this);
    return QWaylandClientExtensionTemplate<TreelandWallpaperManagerV1>::qt_metacast(_clname);
}

int TreelandWallpaperManagerV1::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandClientExtensionTemplate<TreelandWallpaperManagerV1>::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN19TreelandWallpaperV1E_t {};
} // unnamed namespace

template <> constexpr inline auto TreelandWallpaperV1::qt_create_metaobjectdata<qt_meta_tag_ZN19TreelandWallpaperV1E_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TreelandWallpaperV1",
        "failed",
        "",
        "source",
        "Error",
        "error",
        "changed",
        "uint32_t",
        "role",
        "SourceType",
        "sourceType",
        "fileSource",
        "AlreadyUsed",
        "InvalidSource",
        "PermissionDenied",
        "Image",
        "Video",
        "WallpaperRoles",
        "WallpaperRole",
        "Desktop",
        "Lockscreen"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'failed'
        QtMocHelpers::SignalData<void(const QString &, enum Error)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 4, 5 },
        }}),
        // Signal 'changed'
        QtMocHelpers::SignalData<void(uint32_t, enum SourceType, const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 10 }, { QMetaType::QString, 11 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Error'
        QtMocHelpers::EnumData<enum Error>(4, 4, QMC::EnumIsScoped).add({
            {   12, Error::AlreadyUsed },
            {   13, Error::InvalidSource },
            {   14, Error::PermissionDenied },
        }),
        // enum 'SourceType'
        QtMocHelpers::EnumData<enum SourceType>(9, 9, QMC::EnumIsScoped).add({
            {   15, SourceType::Image },
            {   16, SourceType::Video },
        }),
        // flag 'WallpaperRoles'
        QtMocHelpers::EnumData<WallpaperRoles>(17, 18, QMC::EnumIsFlag).add({
            {   19, WallpaperRole::Desktop },
            {   20, WallpaperRole::Lockscreen },
        }),
    };
    return QtMocHelpers::metaObjectData<TreelandWallpaperV1, qt_meta_tag_ZN19TreelandWallpaperV1E_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TreelandWallpaperV1::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19TreelandWallpaperV1E_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19TreelandWallpaperV1E_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19TreelandWallpaperV1E_t>.metaTypes,
    nullptr
} };

void TreelandWallpaperV1::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TreelandWallpaperV1 *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->failed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<enum Error>>(_a[2]))); break;
        case 1: _t->changed((*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<enum SourceType>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TreelandWallpaperV1::*)(const QString & , Error )>(_a, &TreelandWallpaperV1::failed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TreelandWallpaperV1::*)(uint32_t , SourceType , const QString & )>(_a, &TreelandWallpaperV1::changed, 1))
            return;
    }
}

const QMetaObject *TreelandWallpaperV1::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TreelandWallpaperV1::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19TreelandWallpaperV1E_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QtWayland::treeland_wallpaper_v1"))
        return static_cast< QtWayland::treeland_wallpaper_v1*>(this);
    return QObject::qt_metacast(_clname);
}

int TreelandWallpaperV1::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void TreelandWallpaperV1::failed(const QString & _t1, Error _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void TreelandWallpaperV1::changed(uint32_t _t1, SourceType _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
