/****************************************************************************
** Meta object code from reading C++ file 'linuxdmabufer.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../protocols/linuxdmabufer.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'linuxdmabufer.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13LinuxDmaBufV1E_t {};
} // unnamed namespace

template <> constexpr inline auto LinuxDmaBufV1::qt_create_metaobjectdata<qt_meta_tag_ZN13LinuxDmaBufV1E_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LinuxDmaBufV1",
        "formatChanged",
        "",
        "uint32_t",
        "format",
        "modifierChanged",
        "modifierHigh",
        "modifierLow"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'formatChanged'
        QtMocHelpers::SignalData<void(uint32_t)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'modifierChanged'
        QtMocHelpers::SignalData<void(uint32_t, uint32_t, uint32_t)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 3, 6 }, { 0x80000000 | 3, 7 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LinuxDmaBufV1, qt_meta_tag_ZN13LinuxDmaBufV1E_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject LinuxDmaBufV1::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandClientExtensionTemplate<LinuxDmaBufV1>::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13LinuxDmaBufV1E_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13LinuxDmaBufV1E_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13LinuxDmaBufV1E_t>.metaTypes,
    nullptr
} };

void LinuxDmaBufV1::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LinuxDmaBufV1 *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->formatChanged((*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[1]))); break;
        case 1: _t->modifierChanged((*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[3]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (LinuxDmaBufV1::*)(uint32_t )>(_a, &LinuxDmaBufV1::formatChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (LinuxDmaBufV1::*)(uint32_t , uint32_t , uint32_t )>(_a, &LinuxDmaBufV1::modifierChanged, 1))
            return;
    }
}

const QMetaObject *LinuxDmaBufV1::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LinuxDmaBufV1::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13LinuxDmaBufV1E_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QtWayland::zwp_linux_dmabuf_v1"))
        return static_cast< QtWayland::zwp_linux_dmabuf_v1*>(this);
    return QWaylandClientExtensionTemplate<LinuxDmaBufV1>::qt_metacast(_clname);
}

int LinuxDmaBufV1::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandClientExtensionTemplate<LinuxDmaBufV1>::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void LinuxDmaBufV1::formatChanged(uint32_t _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void LinuxDmaBufV1::modifierChanged(uint32_t _t1, uint32_t _t2, uint32_t _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}
namespace {
struct qt_meta_tag_ZN19LinuxBufferParamsV1E_t {};
} // unnamed namespace

template <> constexpr inline auto LinuxBufferParamsV1::qt_create_metaobjectdata<qt_meta_tag_ZN19LinuxBufferParamsV1E_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LinuxBufferParamsV1",
        "created",
        "",
        "wl_buffer*",
        "buffer",
        "failed"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'created'
        QtMocHelpers::SignalData<void(wl_buffer *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'failed'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LinuxBufferParamsV1, qt_meta_tag_ZN19LinuxBufferParamsV1E_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject LinuxBufferParamsV1::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19LinuxBufferParamsV1E_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19LinuxBufferParamsV1E_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19LinuxBufferParamsV1E_t>.metaTypes,
    nullptr
} };

void LinuxBufferParamsV1::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LinuxBufferParamsV1 *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->created((*reinterpret_cast<std::add_pointer_t<wl_buffer*>>(_a[1]))); break;
        case 1: _t->failed(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (LinuxBufferParamsV1::*)(wl_buffer * )>(_a, &LinuxBufferParamsV1::created, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (LinuxBufferParamsV1::*)()>(_a, &LinuxBufferParamsV1::failed, 1))
            return;
    }
}

const QMetaObject *LinuxBufferParamsV1::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LinuxBufferParamsV1::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19LinuxBufferParamsV1E_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QtWayland::zwp_linux_buffer_params_v1"))
        return static_cast< QtWayland::zwp_linux_buffer_params_v1*>(this);
    return QObject::qt_metacast(_clname);
}

int LinuxBufferParamsV1::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void LinuxBufferParamsV1::created(wl_buffer * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void LinuxBufferParamsV1::failed()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
namespace {
struct qt_meta_tag_ZN21LinuxDmaBufFeedbackV1E_t {};
} // unnamed namespace

template <> constexpr inline auto LinuxDmaBufFeedbackV1::qt_create_metaobjectdata<qt_meta_tag_ZN21LinuxDmaBufFeedbackV1E_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LinuxDmaBufFeedbackV1",
        "feedbackDone",
        "",
        "formatTableReceived",
        "fd",
        "size",
        "mainDeviceReceived",
        "const wl_array*",
        "device",
        "trancheDone",
        "trancheTargetDeviceReceived",
        "trancheFormatsReceived",
        "indices",
        "trancheFlagsReceived",
        "flags"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'feedbackDone'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'formatTableReceived'
        QtMocHelpers::SignalData<void(int, uint)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 }, { QMetaType::UInt, 5 },
        }}),
        // Signal 'mainDeviceReceived'
        QtMocHelpers::SignalData<void(const wl_array *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'trancheDone'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'trancheTargetDeviceReceived'
        QtMocHelpers::SignalData<void(const wl_array *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'trancheFormatsReceived'
        QtMocHelpers::SignalData<void(const wl_array *)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 12 },
        }}),
        // Signal 'trancheFlagsReceived'
        QtMocHelpers::SignalData<void(uint)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LinuxDmaBufFeedbackV1, qt_meta_tag_ZN21LinuxDmaBufFeedbackV1E_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject LinuxDmaBufFeedbackV1::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21LinuxDmaBufFeedbackV1E_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21LinuxDmaBufFeedbackV1E_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21LinuxDmaBufFeedbackV1E_t>.metaTypes,
    nullptr
} };

void LinuxDmaBufFeedbackV1::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LinuxDmaBufFeedbackV1 *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->feedbackDone(); break;
        case 1: _t->formatTableReceived((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 2: _t->mainDeviceReceived((*reinterpret_cast<std::add_pointer_t<const wl_array*>>(_a[1]))); break;
        case 3: _t->trancheDone(); break;
        case 4: _t->trancheTargetDeviceReceived((*reinterpret_cast<std::add_pointer_t<const wl_array*>>(_a[1]))); break;
        case 5: _t->trancheFormatsReceived((*reinterpret_cast<std::add_pointer_t<const wl_array*>>(_a[1]))); break;
        case 6: _t->trancheFlagsReceived((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (LinuxDmaBufFeedbackV1::*)()>(_a, &LinuxDmaBufFeedbackV1::feedbackDone, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (LinuxDmaBufFeedbackV1::*)(int , uint )>(_a, &LinuxDmaBufFeedbackV1::formatTableReceived, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (LinuxDmaBufFeedbackV1::*)(const wl_array * )>(_a, &LinuxDmaBufFeedbackV1::mainDeviceReceived, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (LinuxDmaBufFeedbackV1::*)()>(_a, &LinuxDmaBufFeedbackV1::trancheDone, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (LinuxDmaBufFeedbackV1::*)(const wl_array * )>(_a, &LinuxDmaBufFeedbackV1::trancheTargetDeviceReceived, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (LinuxDmaBufFeedbackV1::*)(const wl_array * )>(_a, &LinuxDmaBufFeedbackV1::trancheFormatsReceived, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (LinuxDmaBufFeedbackV1::*)(uint )>(_a, &LinuxDmaBufFeedbackV1::trancheFlagsReceived, 6))
            return;
    }
}

const QMetaObject *LinuxDmaBufFeedbackV1::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LinuxDmaBufFeedbackV1::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21LinuxDmaBufFeedbackV1E_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QtWayland::zwp_linux_dmabuf_feedback_v1"))
        return static_cast< QtWayland::zwp_linux_dmabuf_feedback_v1*>(this);
    return QObject::qt_metacast(_clname);
}

int LinuxDmaBufFeedbackV1::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void LinuxDmaBufFeedbackV1::feedbackDone()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void LinuxDmaBufFeedbackV1::formatTableReceived(int _t1, uint _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void LinuxDmaBufFeedbackV1::mainDeviceReceived(const wl_array * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void LinuxDmaBufFeedbackV1::trancheDone()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void LinuxDmaBufFeedbackV1::trancheTargetDeviceReceived(const wl_array * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void LinuxDmaBufFeedbackV1::trancheFormatsReceived(const wl_array * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void LinuxDmaBufFeedbackV1::trancheFlagsReceived(uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
