// This file was generated by qtwaylandscanner
// source file is ext-image-copy-capture-v1.xml

#include "qwayland-ext-image-copy-capture-v1.h"

QT_BEGIN_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_GCC("-Wmissing-field-initializers")
QT_WARNING_DISABLE_CLANG("-Wmissing-field-initializers")

namespace QtWayland {

static inline void *wlRegistryBind(struct ::wl_registry *registry, uint32_t name, const struct ::wl_interface *interface, uint32_t version)
{
    const uint32_t bindOpCode = 0;
    return (void *) wl_proxy_marshal_constructor_versioned((struct wl_proxy *) registry,
    bindOpCode, interface, version, name, interface->name, version, nullptr);
}

    ext_image_copy_capture_manager_v1::ext_image_copy_capture_manager_v1(struct ::wl_registry *registry, uint32_t id, int version)
    {
        init(registry, id, version);
    }

    ext_image_copy_capture_manager_v1::ext_image_copy_capture_manager_v1(struct ::ext_image_copy_capture_manager_v1 *obj)
        : m_ext_image_copy_capture_manager_v1(obj)
    {
    }

    ext_image_copy_capture_manager_v1::ext_image_copy_capture_manager_v1()
        : m_ext_image_copy_capture_manager_v1(nullptr)
    {
    }

    ext_image_copy_capture_manager_v1::~ext_image_copy_capture_manager_v1()
    {
    }

    void ext_image_copy_capture_manager_v1::init(struct ::wl_registry *registry, uint32_t id, int version)
    {
        m_ext_image_copy_capture_manager_v1 = static_cast<struct ::ext_image_copy_capture_manager_v1 *>(wlRegistryBind(registry, id, &ext_image_copy_capture_manager_v1_interface, version));
    }

    void ext_image_copy_capture_manager_v1::init(struct ::ext_image_copy_capture_manager_v1 *obj)
    {
        m_ext_image_copy_capture_manager_v1 = obj;
    }

    ext_image_copy_capture_manager_v1 *ext_image_copy_capture_manager_v1::fromObject(struct ::ext_image_copy_capture_manager_v1 *object)
    {
        return static_cast<ext_image_copy_capture_manager_v1 *>(ext_image_copy_capture_manager_v1_get_user_data(object));
    }

    bool ext_image_copy_capture_manager_v1::isInitialized() const
    {
        return m_ext_image_copy_capture_manager_v1 != nullptr;
    }

    uint32_t ext_image_copy_capture_manager_v1::version() const
    {
        return wl_proxy_get_version(reinterpret_cast<wl_proxy*>(m_ext_image_copy_capture_manager_v1));
    }

    const struct wl_interface *ext_image_copy_capture_manager_v1::interface()
    {
        return &::ext_image_copy_capture_manager_v1_interface;
    }

    struct ::ext_image_copy_capture_session_v1 *ext_image_copy_capture_manager_v1::create_session(struct ::ext_image_capture_source_v1 *source, uint32_t options)
    {
        struct ::ext_image_copy_capture_session_v1 * session = ::ext_image_copy_capture_manager_v1_create_session(
            m_ext_image_copy_capture_manager_v1,
            source,
            options);
        return session;
    }

    struct ::ext_image_copy_capture_cursor_session_v1 *ext_image_copy_capture_manager_v1::create_pointer_cursor_session(struct ::ext_image_capture_source_v1 *source, struct ::wl_pointer *pointer)
    {
        struct ::ext_image_copy_capture_cursor_session_v1 * session = ::ext_image_copy_capture_manager_v1_create_pointer_cursor_session(
            m_ext_image_copy_capture_manager_v1,
            source,
            pointer);
        return session;
    }

    void ext_image_copy_capture_manager_v1::destroy()
    {
        ::ext_image_copy_capture_manager_v1_destroy(
            m_ext_image_copy_capture_manager_v1);
        m_ext_image_copy_capture_manager_v1 = nullptr;
    }

    ext_image_copy_capture_session_v1::ext_image_copy_capture_session_v1(struct ::wl_registry *registry, uint32_t id, int version)
    {
        init(registry, id, version);
    }

    ext_image_copy_capture_session_v1::ext_image_copy_capture_session_v1(struct ::ext_image_copy_capture_session_v1 *obj)
        : m_ext_image_copy_capture_session_v1(obj)
    {
        init_listener();
    }

    ext_image_copy_capture_session_v1::ext_image_copy_capture_session_v1()
        : m_ext_image_copy_capture_session_v1(nullptr)
    {
    }

    ext_image_copy_capture_session_v1::~ext_image_copy_capture_session_v1()
    {
    }

    void ext_image_copy_capture_session_v1::init(struct ::wl_registry *registry, uint32_t id, int version)
    {
        m_ext_image_copy_capture_session_v1 = static_cast<struct ::ext_image_copy_capture_session_v1 *>(wlRegistryBind(registry, id, &ext_image_copy_capture_session_v1_interface, version));
        init_listener();
    }

    void ext_image_copy_capture_session_v1::init(struct ::ext_image_copy_capture_session_v1 *obj)
    {
        m_ext_image_copy_capture_session_v1 = obj;
        init_listener();
    }

    ext_image_copy_capture_session_v1 *ext_image_copy_capture_session_v1::fromObject(struct ::ext_image_copy_capture_session_v1 *object)
    {
        if (wl_proxy_get_listener((struct ::wl_proxy *)object) != (void *)&m_ext_image_copy_capture_session_v1_listener)
            return nullptr;
        return static_cast<ext_image_copy_capture_session_v1 *>(ext_image_copy_capture_session_v1_get_user_data(object));
    }

    bool ext_image_copy_capture_session_v1::isInitialized() const
    {
        return m_ext_image_copy_capture_session_v1 != nullptr;
    }

    uint32_t ext_image_copy_capture_session_v1::version() const
    {
        return wl_proxy_get_version(reinterpret_cast<wl_proxy*>(m_ext_image_copy_capture_session_v1));
    }

    const struct wl_interface *ext_image_copy_capture_session_v1::interface()
    {
        return &::ext_image_copy_capture_session_v1_interface;
    }

    struct ::ext_image_copy_capture_frame_v1 *ext_image_copy_capture_session_v1::create_frame()
    {
        struct ::ext_image_copy_capture_frame_v1 * frame = ::ext_image_copy_capture_session_v1_create_frame(
            m_ext_image_copy_capture_session_v1);
        return frame;
    }

    void ext_image_copy_capture_session_v1::destroy()
    {
        ::ext_image_copy_capture_session_v1_destroy(
            m_ext_image_copy_capture_session_v1);
        m_ext_image_copy_capture_session_v1 = nullptr;
    }

    void ext_image_copy_capture_session_v1::ext_image_copy_capture_session_v1_buffer_size(uint32_t , uint32_t )
    {
    }

    void ext_image_copy_capture_session_v1::handle_buffer_size(
        void *data,
        struct ::ext_image_copy_capture_session_v1 *object,
        uint32_t width,
        uint32_t height)
    {
        Q_UNUSED(object);
        static_cast<ext_image_copy_capture_session_v1 *>(data)->ext_image_copy_capture_session_v1_buffer_size(
            width,
            height);
    }

    void ext_image_copy_capture_session_v1::ext_image_copy_capture_session_v1_shm_format(uint32_t )
    {
    }

    void ext_image_copy_capture_session_v1::handle_shm_format(
        void *data,
        struct ::ext_image_copy_capture_session_v1 *object,
        uint32_t format)
    {
        Q_UNUSED(object);
        static_cast<ext_image_copy_capture_session_v1 *>(data)->ext_image_copy_capture_session_v1_shm_format(
            format);
    }

    void ext_image_copy_capture_session_v1::ext_image_copy_capture_session_v1_dmabuf_device(wl_array *)
    {
    }

    void ext_image_copy_capture_session_v1::handle_dmabuf_device(
        void *data,
        struct ::ext_image_copy_capture_session_v1 *object,
        wl_array *device)
    {
        Q_UNUSED(object);
        static_cast<ext_image_copy_capture_session_v1 *>(data)->ext_image_copy_capture_session_v1_dmabuf_device(
            device);
    }

    void ext_image_copy_capture_session_v1::ext_image_copy_capture_session_v1_dmabuf_format(uint32_t , wl_array *)
    {
    }

    void ext_image_copy_capture_session_v1::handle_dmabuf_format(
        void *data,
        struct ::ext_image_copy_capture_session_v1 *object,
        uint32_t format,
        wl_array *modifiers)
    {
        Q_UNUSED(object);
        static_cast<ext_image_copy_capture_session_v1 *>(data)->ext_image_copy_capture_session_v1_dmabuf_format(
            format,
            modifiers);
    }

    void ext_image_copy_capture_session_v1::ext_image_copy_capture_session_v1_done()
    {
    }

    void ext_image_copy_capture_session_v1::handle_done(
        void *data,
        struct ::ext_image_copy_capture_session_v1 *object)
    {
        Q_UNUSED(object);
        static_cast<ext_image_copy_capture_session_v1 *>(data)->ext_image_copy_capture_session_v1_done();
    }

    void ext_image_copy_capture_session_v1::ext_image_copy_capture_session_v1_stopped()
    {
    }

    void ext_image_copy_capture_session_v1::handle_stopped(
        void *data,
        struct ::ext_image_copy_capture_session_v1 *object)
    {
        Q_UNUSED(object);
        static_cast<ext_image_copy_capture_session_v1 *>(data)->ext_image_copy_capture_session_v1_stopped();
    }

    const struct ext_image_copy_capture_session_v1_listener ext_image_copy_capture_session_v1::m_ext_image_copy_capture_session_v1_listener = {
        ext_image_copy_capture_session_v1::handle_buffer_size,
        ext_image_copy_capture_session_v1::handle_shm_format,
        ext_image_copy_capture_session_v1::handle_dmabuf_device,
        ext_image_copy_capture_session_v1::handle_dmabuf_format,
        ext_image_copy_capture_session_v1::handle_done,
        ext_image_copy_capture_session_v1::handle_stopped,
    };

    void ext_image_copy_capture_session_v1::init_listener()
    {
        ext_image_copy_capture_session_v1_add_listener(m_ext_image_copy_capture_session_v1, &m_ext_image_copy_capture_session_v1_listener, this);
    }

    ext_image_copy_capture_frame_v1::ext_image_copy_capture_frame_v1(struct ::wl_registry *registry, uint32_t id, int version)
    {
        init(registry, id, version);
    }

    ext_image_copy_capture_frame_v1::ext_image_copy_capture_frame_v1(struct ::ext_image_copy_capture_frame_v1 *obj)
        : m_ext_image_copy_capture_frame_v1(obj)
    {
        init_listener();
    }

    ext_image_copy_capture_frame_v1::ext_image_copy_capture_frame_v1()
        : m_ext_image_copy_capture_frame_v1(nullptr)
    {
    }

    ext_image_copy_capture_frame_v1::~ext_image_copy_capture_frame_v1()
    {
    }

    void ext_image_copy_capture_frame_v1::init(struct ::wl_registry *registry, uint32_t id, int version)
    {
        m_ext_image_copy_capture_frame_v1 = static_cast<struct ::ext_image_copy_capture_frame_v1 *>(wlRegistryBind(registry, id, &ext_image_copy_capture_frame_v1_interface, version));
        init_listener();
    }

    void ext_image_copy_capture_frame_v1::init(struct ::ext_image_copy_capture_frame_v1 *obj)
    {
        m_ext_image_copy_capture_frame_v1 = obj;
        init_listener();
    }

    ext_image_copy_capture_frame_v1 *ext_image_copy_capture_frame_v1::fromObject(struct ::ext_image_copy_capture_frame_v1 *object)
    {
        if (wl_proxy_get_listener((struct ::wl_proxy *)object) != (void *)&m_ext_image_copy_capture_frame_v1_listener)
            return nullptr;
        return static_cast<ext_image_copy_capture_frame_v1 *>(ext_image_copy_capture_frame_v1_get_user_data(object));
    }

    bool ext_image_copy_capture_frame_v1::isInitialized() const
    {
        return m_ext_image_copy_capture_frame_v1 != nullptr;
    }

    uint32_t ext_image_copy_capture_frame_v1::version() const
    {
        return wl_proxy_get_version(reinterpret_cast<wl_proxy*>(m_ext_image_copy_capture_frame_v1));
    }

    const struct wl_interface *ext_image_copy_capture_frame_v1::interface()
    {
        return &::ext_image_copy_capture_frame_v1_interface;
    }

    void ext_image_copy_capture_frame_v1::destroy()
    {
        ::ext_image_copy_capture_frame_v1_destroy(
            m_ext_image_copy_capture_frame_v1);
        m_ext_image_copy_capture_frame_v1 = nullptr;
    }

    void ext_image_copy_capture_frame_v1::attach_buffer(struct ::wl_buffer *buffer)
    {
        ::ext_image_copy_capture_frame_v1_attach_buffer(
            m_ext_image_copy_capture_frame_v1,
            buffer);
    }

    void ext_image_copy_capture_frame_v1::damage_buffer(int32_t x, int32_t y, int32_t width, int32_t height)
    {
        ::ext_image_copy_capture_frame_v1_damage_buffer(
            m_ext_image_copy_capture_frame_v1,
            x,
            y,
            width,
            height);
    }

    void ext_image_copy_capture_frame_v1::capture()
    {
        ::ext_image_copy_capture_frame_v1_capture(
            m_ext_image_copy_capture_frame_v1);
    }

    void ext_image_copy_capture_frame_v1::ext_image_copy_capture_frame_v1_transform(uint32_t )
    {
    }

    void ext_image_copy_capture_frame_v1::handle_transform(
        void *data,
        struct ::ext_image_copy_capture_frame_v1 *object,
        uint32_t transform)
    {
        Q_UNUSED(object);
        static_cast<ext_image_copy_capture_frame_v1 *>(data)->ext_image_copy_capture_frame_v1_transform(
            transform);
    }

    void ext_image_copy_capture_frame_v1::ext_image_copy_capture_frame_v1_damage(int32_t , int32_t , int32_t , int32_t )
    {
    }

    void ext_image_copy_capture_frame_v1::handle_damage(
        void *data,
        struct ::ext_image_copy_capture_frame_v1 *object,
        int32_t x,
        int32_t y,
        int32_t width,
        int32_t height)
    {
        Q_UNUSED(object);
        static_cast<ext_image_copy_capture_frame_v1 *>(data)->ext_image_copy_capture_frame_v1_damage(
            x,
            y,
            width,
            height);
    }

    void ext_image_copy_capture_frame_v1::ext_image_copy_capture_frame_v1_presentation_time(uint32_t , uint32_t , uint32_t )
    {
    }

    void ext_image_copy_capture_frame_v1::handle_presentation_time(
        void *data,
        struct ::ext_image_copy_capture_frame_v1 *object,
        uint32_t tv_sec_hi,
        uint32_t tv_sec_lo,
        uint32_t tv_nsec)
    {
        Q_UNUSED(object);
        static_cast<ext_image_copy_capture_frame_v1 *>(data)->ext_image_copy_capture_frame_v1_presentation_time(
            tv_sec_hi,
            tv_sec_lo,
            tv_nsec);
    }

    void ext_image_copy_capture_frame_v1::ext_image_copy_capture_frame_v1_ready()
    {
    }

    void ext_image_copy_capture_frame_v1::handle_ready(
        void *data,
        struct ::ext_image_copy_capture_frame_v1 *object)
    {
        Q_UNUSED(object);
        static_cast<ext_image_copy_capture_frame_v1 *>(data)->ext_image_copy_capture_frame_v1_ready();
    }

    void ext_image_copy_capture_frame_v1::ext_image_copy_capture_frame_v1_failed(uint32_t )
    {
    }

    void ext_image_copy_capture_frame_v1::handle_failed(
        void *data,
        struct ::ext_image_copy_capture_frame_v1 *object,
        uint32_t reason)
    {
        Q_UNUSED(object);
        static_cast<ext_image_copy_capture_frame_v1 *>(data)->ext_image_copy_capture_frame_v1_failed(
            reason);
    }

    const struct ext_image_copy_capture_frame_v1_listener ext_image_copy_capture_frame_v1::m_ext_image_copy_capture_frame_v1_listener = {
        ext_image_copy_capture_frame_v1::handle_transform,
        ext_image_copy_capture_frame_v1::handle_damage,
        ext_image_copy_capture_frame_v1::handle_presentation_time,
        ext_image_copy_capture_frame_v1::handle_ready,
        ext_image_copy_capture_frame_v1::handle_failed,
    };

    void ext_image_copy_capture_frame_v1::init_listener()
    {
        ext_image_copy_capture_frame_v1_add_listener(m_ext_image_copy_capture_frame_v1, &m_ext_image_copy_capture_frame_v1_listener, this);
    }

    ext_image_copy_capture_cursor_session_v1::ext_image_copy_capture_cursor_session_v1(struct ::wl_registry *registry, uint32_t id, int version)
    {
        init(registry, id, version);
    }

    ext_image_copy_capture_cursor_session_v1::ext_image_copy_capture_cursor_session_v1(struct ::ext_image_copy_capture_cursor_session_v1 *obj)
        : m_ext_image_copy_capture_cursor_session_v1(obj)
    {
        init_listener();
    }

    ext_image_copy_capture_cursor_session_v1::ext_image_copy_capture_cursor_session_v1()
        : m_ext_image_copy_capture_cursor_session_v1(nullptr)
    {
    }

    ext_image_copy_capture_cursor_session_v1::~ext_image_copy_capture_cursor_session_v1()
    {
    }

    void ext_image_copy_capture_cursor_session_v1::init(struct ::wl_registry *registry, uint32_t id, int version)
    {
        m_ext_image_copy_capture_cursor_session_v1 = static_cast<struct ::ext_image_copy_capture_cursor_session_v1 *>(wlRegistryBind(registry, id, &ext_image_copy_capture_cursor_session_v1_interface, version));
        init_listener();
    }

    void ext_image_copy_capture_cursor_session_v1::init(struct ::ext_image_copy_capture_cursor_session_v1 *obj)
    {
        m_ext_image_copy_capture_cursor_session_v1 = obj;
        init_listener();
    }

    ext_image_copy_capture_cursor_session_v1 *ext_image_copy_capture_cursor_session_v1::fromObject(struct ::ext_image_copy_capture_cursor_session_v1 *object)
    {
        if (wl_proxy_get_listener((struct ::wl_proxy *)object) != (void *)&m_ext_image_copy_capture_cursor_session_v1_listener)
            return nullptr;
        return static_cast<ext_image_copy_capture_cursor_session_v1 *>(ext_image_copy_capture_cursor_session_v1_get_user_data(object));
    }

    bool ext_image_copy_capture_cursor_session_v1::isInitialized() const
    {
        return m_ext_image_copy_capture_cursor_session_v1 != nullptr;
    }

    uint32_t ext_image_copy_capture_cursor_session_v1::version() const
    {
        return wl_proxy_get_version(reinterpret_cast<wl_proxy*>(m_ext_image_copy_capture_cursor_session_v1));
    }

    const struct wl_interface *ext_image_copy_capture_cursor_session_v1::interface()
    {
        return &::ext_image_copy_capture_cursor_session_v1_interface;
    }

    void ext_image_copy_capture_cursor_session_v1::destroy()
    {
        ::ext_image_copy_capture_cursor_session_v1_destroy(
            m_ext_image_copy_capture_cursor_session_v1);
        m_ext_image_copy_capture_cursor_session_v1 = nullptr;
    }

    struct ::ext_image_copy_capture_session_v1 *ext_image_copy_capture_cursor_session_v1::get_capture_session()
    {
        struct ::ext_image_copy_capture_session_v1 * session = ::ext_image_copy_capture_cursor_session_v1_get_capture_session(
            m_ext_image_copy_capture_cursor_session_v1);
        return session;
    }

    void ext_image_copy_capture_cursor_session_v1::ext_image_copy_capture_cursor_session_v1_enter()
    {
    }

    void ext_image_copy_capture_cursor_session_v1::handle_enter(
        void *data,
        struct ::ext_image_copy_capture_cursor_session_v1 *object)
    {
        Q_UNUSED(object);
        static_cast<ext_image_copy_capture_cursor_session_v1 *>(data)->ext_image_copy_capture_cursor_session_v1_enter();
    }

    void ext_image_copy_capture_cursor_session_v1::ext_image_copy_capture_cursor_session_v1_leave()
    {
    }

    void ext_image_copy_capture_cursor_session_v1::handle_leave(
        void *data,
        struct ::ext_image_copy_capture_cursor_session_v1 *object)
    {
        Q_UNUSED(object);
        static_cast<ext_image_copy_capture_cursor_session_v1 *>(data)->ext_image_copy_capture_cursor_session_v1_leave();
    }

    void ext_image_copy_capture_cursor_session_v1::ext_image_copy_capture_cursor_session_v1_position(int32_t , int32_t )
    {
    }

    void ext_image_copy_capture_cursor_session_v1::handle_position(
        void *data,
        struct ::ext_image_copy_capture_cursor_session_v1 *object,
        int32_t x,
        int32_t y)
    {
        Q_UNUSED(object);
        static_cast<ext_image_copy_capture_cursor_session_v1 *>(data)->ext_image_copy_capture_cursor_session_v1_position(
            x,
            y);
    }

    void ext_image_copy_capture_cursor_session_v1::ext_image_copy_capture_cursor_session_v1_hotspot(int32_t , int32_t )
    {
    }

    void ext_image_copy_capture_cursor_session_v1::handle_hotspot(
        void *data,
        struct ::ext_image_copy_capture_cursor_session_v1 *object,
        int32_t x,
        int32_t y)
    {
        Q_UNUSED(object);
        static_cast<ext_image_copy_capture_cursor_session_v1 *>(data)->ext_image_copy_capture_cursor_session_v1_hotspot(
            x,
            y);
    }

    const struct ext_image_copy_capture_cursor_session_v1_listener ext_image_copy_capture_cursor_session_v1::m_ext_image_copy_capture_cursor_session_v1_listener = {
        ext_image_copy_capture_cursor_session_v1::handle_enter,
        ext_image_copy_capture_cursor_session_v1::handle_leave,
        ext_image_copy_capture_cursor_session_v1::handle_position,
        ext_image_copy_capture_cursor_session_v1::handle_hotspot,
    };

    void ext_image_copy_capture_cursor_session_v1::init_listener()
    {
        ext_image_copy_capture_cursor_session_v1_add_listener(m_ext_image_copy_capture_cursor_session_v1, &m_ext_image_copy_capture_cursor_session_v1_listener, this);
    }
}

QT_WARNING_POP
QT_END_NAMESPACE
