/****************************************************************************
** Meta object code from reading C++ file 'treelandcapture.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../protocols/treelandcapture.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'treelandcapture.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN20TreeLandCaptureFrameE_t {};
} // unnamed namespace

template <> constexpr inline auto TreeLandCaptureFrame::qt_create_metaobjectdata<qt_meta_tag_ZN20TreeLandCaptureFrameE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TreeLandCaptureFrame",
        "ready",
        "",
        "QImage",
        "image",
        "failed"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ready'
        QtMocHelpers::SignalData<void(QImage)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'failed'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TreeLandCaptureFrame, qt_meta_tag_ZN20TreeLandCaptureFrameE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TreeLandCaptureFrame::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20TreeLandCaptureFrameE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20TreeLandCaptureFrameE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN20TreeLandCaptureFrameE_t>.metaTypes,
    nullptr
} };

void TreeLandCaptureFrame::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TreeLandCaptureFrame *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ready((*reinterpret_cast<std::add_pointer_t<QImage>>(_a[1]))); break;
        case 1: _t->failed(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TreeLandCaptureFrame::*)(QImage )>(_a, &TreeLandCaptureFrame::ready, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TreeLandCaptureFrame::*)()>(_a, &TreeLandCaptureFrame::failed, 1))
            return;
    }
}

const QMetaObject *TreeLandCaptureFrame::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TreeLandCaptureFrame::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN20TreeLandCaptureFrameE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QtWayland::treeland_capture_frame_v1"))
        return static_cast< QtWayland::treeland_capture_frame_v1*>(this);
    return QObject::qt_metacast(_clname);
}

int TreeLandCaptureFrame::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void TreeLandCaptureFrame::ready(QImage _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void TreeLandCaptureFrame::failed()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
namespace {
struct qt_meta_tag_ZN22TreeLandCaptureContextE_t {};
} // unnamed namespace

template <> constexpr inline auto TreeLandCaptureContext::qt_create_metaobjectdata<qt_meta_tag_ZN22TreeLandCaptureContextE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TreeLandCaptureContext",
        "sourceReady",
        "",
        "QRect",
        "region",
        "uint32_t",
        "sourceType",
        "sourceFailed",
        "reason"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sourceReady'
        QtMocHelpers::SignalData<void(QRect, uint32_t)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'sourceFailed'
        QtMocHelpers::SignalData<void(uint32_t)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TreeLandCaptureContext, qt_meta_tag_ZN22TreeLandCaptureContextE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TreeLandCaptureContext::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22TreeLandCaptureContextE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22TreeLandCaptureContextE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22TreeLandCaptureContextE_t>.metaTypes,
    nullptr
} };

void TreeLandCaptureContext::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TreeLandCaptureContext *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sourceReady((*reinterpret_cast<std::add_pointer_t<QRect>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[2]))); break;
        case 1: _t->sourceFailed((*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TreeLandCaptureContext::*)(QRect , uint32_t )>(_a, &TreeLandCaptureContext::sourceReady, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TreeLandCaptureContext::*)(uint32_t )>(_a, &TreeLandCaptureContext::sourceFailed, 1))
            return;
    }
}

const QMetaObject *TreeLandCaptureContext::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TreeLandCaptureContext::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22TreeLandCaptureContextE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QtWayland::treeland_capture_context_v1"))
        return static_cast< QtWayland::treeland_capture_context_v1*>(this);
    return QObject::qt_metacast(_clname);
}

int TreeLandCaptureContext::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void TreeLandCaptureContext::sourceReady(QRect _t1, uint32_t _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void TreeLandCaptureContext::sourceFailed(uint32_t _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN22TreeLandCaptureManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto TreeLandCaptureManager::qt_create_metaobjectdata<qt_meta_tag_ZN22TreeLandCaptureManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TreeLandCaptureManager"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TreeLandCaptureManager, qt_meta_tag_ZN22TreeLandCaptureManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TreeLandCaptureManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandClientExtensionTemplate<TreeLandCaptureManager,destruct_treeland_capture_manager>::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22TreeLandCaptureManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22TreeLandCaptureManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22TreeLandCaptureManagerE_t>.metaTypes,
    nullptr
} };

void TreeLandCaptureManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TreeLandCaptureManager *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *TreeLandCaptureManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TreeLandCaptureManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22TreeLandCaptureManagerE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QtWayland::treeland_capture_manager_v1"))
        return static_cast< QtWayland::treeland_capture_manager_v1*>(this);
    return QWaylandClientExtensionTemplate<TreeLandCaptureManager,destruct_treeland_capture_manager>::qt_metacast(_clname);
}

int TreeLandCaptureManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandClientExtensionTemplate<TreeLandCaptureManager,destruct_treeland_capture_manager>::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
