// This file was generated by qtwaylandscanner
// source file is linux-dmabuf-unstable-v1.xml

#include "qwayland-linux-dmabuf-unstable-v1.h"

QT_BEGIN_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_GCC("-Wmissing-field-initializers")
QT_WARNING_DISABLE_CLANG("-Wmissing-field-initializers")

namespace QtWayland {

static inline void *wlRegistryBind(struct ::wl_registry *registry, uint32_t name, const struct ::wl_interface *interface, uint32_t version)
{
    const uint32_t bindOpCode = 0;
    return (void *) wl_proxy_marshal_constructor_versioned((struct wl_proxy *) registry,
    bindOpCode, interface, version, name, interface->name, version, nullptr);
}

    zwp_linux_dmabuf_v1::zwp_linux_dmabuf_v1(struct ::wl_registry *registry, uint32_t id, int version)
    {
        init(registry, id, version);
    }

    zwp_linux_dmabuf_v1::zwp_linux_dmabuf_v1(struct ::zwp_linux_dmabuf_v1 *obj)
        : m_zwp_linux_dmabuf_v1(obj)
    {
        init_listener();
    }

    zwp_linux_dmabuf_v1::zwp_linux_dmabuf_v1()
        : m_zwp_linux_dmabuf_v1(nullptr)
    {
    }

    zwp_linux_dmabuf_v1::~zwp_linux_dmabuf_v1()
    {
    }

    void zwp_linux_dmabuf_v1::init(struct ::wl_registry *registry, uint32_t id, int version)
    {
        m_zwp_linux_dmabuf_v1 = static_cast<struct ::zwp_linux_dmabuf_v1 *>(wlRegistryBind(registry, id, &zwp_linux_dmabuf_v1_interface, version));
        init_listener();
    }

    void zwp_linux_dmabuf_v1::init(struct ::zwp_linux_dmabuf_v1 *obj)
    {
        m_zwp_linux_dmabuf_v1 = obj;
        init_listener();
    }

    zwp_linux_dmabuf_v1 *zwp_linux_dmabuf_v1::fromObject(struct ::zwp_linux_dmabuf_v1 *object)
    {
        if (wl_proxy_get_listener((struct ::wl_proxy *)object) != (void *)&m_zwp_linux_dmabuf_v1_listener)
            return nullptr;
        return static_cast<zwp_linux_dmabuf_v1 *>(zwp_linux_dmabuf_v1_get_user_data(object));
    }

    bool zwp_linux_dmabuf_v1::isInitialized() const
    {
        return m_zwp_linux_dmabuf_v1 != nullptr;
    }

    uint32_t zwp_linux_dmabuf_v1::version() const
    {
        return wl_proxy_get_version(reinterpret_cast<wl_proxy*>(m_zwp_linux_dmabuf_v1));
    }

    const struct wl_interface *zwp_linux_dmabuf_v1::interface()
    {
        return &::zwp_linux_dmabuf_v1_interface;
    }

    void zwp_linux_dmabuf_v1::destroy()
    {
        ::zwp_linux_dmabuf_v1_destroy(
            m_zwp_linux_dmabuf_v1);
        m_zwp_linux_dmabuf_v1 = nullptr;
    }

    struct ::zwp_linux_buffer_params_v1 *zwp_linux_dmabuf_v1::create_params()
    {
        struct ::zwp_linux_buffer_params_v1 * params_id = ::zwp_linux_dmabuf_v1_create_params(
            m_zwp_linux_dmabuf_v1);
        return params_id;
    }

    struct ::zwp_linux_dmabuf_feedback_v1 *zwp_linux_dmabuf_v1::get_default_feedback()
    {
        struct ::zwp_linux_dmabuf_feedback_v1 * id = ::zwp_linux_dmabuf_v1_get_default_feedback(
            m_zwp_linux_dmabuf_v1);
        return id;
    }

    struct ::zwp_linux_dmabuf_feedback_v1 *zwp_linux_dmabuf_v1::get_surface_feedback(struct ::wl_surface *surface)
    {
        struct ::zwp_linux_dmabuf_feedback_v1 * id = ::zwp_linux_dmabuf_v1_get_surface_feedback(
            m_zwp_linux_dmabuf_v1,
            surface);
        return id;
    }

    void zwp_linux_dmabuf_v1::zwp_linux_dmabuf_v1_format(uint32_t )
    {
    }

    void zwp_linux_dmabuf_v1::handle_format(
        void *data,
        struct ::zwp_linux_dmabuf_v1 *object,
        uint32_t format)
    {
        Q_UNUSED(object);
        static_cast<zwp_linux_dmabuf_v1 *>(data)->zwp_linux_dmabuf_v1_format(
            format);
    }

    void zwp_linux_dmabuf_v1::zwp_linux_dmabuf_v1_modifier(uint32_t , uint32_t , uint32_t )
    {
    }

    void zwp_linux_dmabuf_v1::handle_modifier(
        void *data,
        struct ::zwp_linux_dmabuf_v1 *object,
        uint32_t format,
        uint32_t modifier_hi,
        uint32_t modifier_lo)
    {
        Q_UNUSED(object);
        static_cast<zwp_linux_dmabuf_v1 *>(data)->zwp_linux_dmabuf_v1_modifier(
            format,
            modifier_hi,
            modifier_lo);
    }

    const struct zwp_linux_dmabuf_v1_listener zwp_linux_dmabuf_v1::m_zwp_linux_dmabuf_v1_listener = {
        zwp_linux_dmabuf_v1::handle_format,
        zwp_linux_dmabuf_v1::handle_modifier,
    };

    void zwp_linux_dmabuf_v1::init_listener()
    {
        zwp_linux_dmabuf_v1_add_listener(m_zwp_linux_dmabuf_v1, &m_zwp_linux_dmabuf_v1_listener, this);
    }

    zwp_linux_buffer_params_v1::zwp_linux_buffer_params_v1(struct ::wl_registry *registry, uint32_t id, int version)
    {
        init(registry, id, version);
    }

    zwp_linux_buffer_params_v1::zwp_linux_buffer_params_v1(struct ::zwp_linux_buffer_params_v1 *obj)
        : m_zwp_linux_buffer_params_v1(obj)
    {
        init_listener();
    }

    zwp_linux_buffer_params_v1::zwp_linux_buffer_params_v1()
        : m_zwp_linux_buffer_params_v1(nullptr)
    {
    }

    zwp_linux_buffer_params_v1::~zwp_linux_buffer_params_v1()
    {
    }

    void zwp_linux_buffer_params_v1::init(struct ::wl_registry *registry, uint32_t id, int version)
    {
        m_zwp_linux_buffer_params_v1 = static_cast<struct ::zwp_linux_buffer_params_v1 *>(wlRegistryBind(registry, id, &zwp_linux_buffer_params_v1_interface, version));
        init_listener();
    }

    void zwp_linux_buffer_params_v1::init(struct ::zwp_linux_buffer_params_v1 *obj)
    {
        m_zwp_linux_buffer_params_v1 = obj;
        init_listener();
    }

    zwp_linux_buffer_params_v1 *zwp_linux_buffer_params_v1::fromObject(struct ::zwp_linux_buffer_params_v1 *object)
    {
        if (wl_proxy_get_listener((struct ::wl_proxy *)object) != (void *)&m_zwp_linux_buffer_params_v1_listener)
            return nullptr;
        return static_cast<zwp_linux_buffer_params_v1 *>(zwp_linux_buffer_params_v1_get_user_data(object));
    }

    bool zwp_linux_buffer_params_v1::isInitialized() const
    {
        return m_zwp_linux_buffer_params_v1 != nullptr;
    }

    uint32_t zwp_linux_buffer_params_v1::version() const
    {
        return wl_proxy_get_version(reinterpret_cast<wl_proxy*>(m_zwp_linux_buffer_params_v1));
    }

    const struct wl_interface *zwp_linux_buffer_params_v1::interface()
    {
        return &::zwp_linux_buffer_params_v1_interface;
    }

    void zwp_linux_buffer_params_v1::destroy()
    {
        ::zwp_linux_buffer_params_v1_destroy(
            m_zwp_linux_buffer_params_v1);
        m_zwp_linux_buffer_params_v1 = nullptr;
    }

    void zwp_linux_buffer_params_v1::add(int32_t fd, uint32_t plane_idx, uint32_t offset, uint32_t stride, uint32_t modifier_hi, uint32_t modifier_lo)
    {
        ::zwp_linux_buffer_params_v1_add(
            m_zwp_linux_buffer_params_v1,
            fd,
            plane_idx,
            offset,
            stride,
            modifier_hi,
            modifier_lo);
    }

    void zwp_linux_buffer_params_v1::create(int32_t width, int32_t height, uint32_t format, uint32_t flags)
    {
        ::zwp_linux_buffer_params_v1_create(
            m_zwp_linux_buffer_params_v1,
            width,
            height,
            format,
            flags);
    }

    struct ::wl_buffer *zwp_linux_buffer_params_v1::create_immed(int32_t width, int32_t height, uint32_t format, uint32_t flags)
    {
        struct ::wl_buffer * buffer_id = ::zwp_linux_buffer_params_v1_create_immed(
            m_zwp_linux_buffer_params_v1,
            width,
            height,
            format,
            flags);
        return buffer_id;
    }

    void zwp_linux_buffer_params_v1::zwp_linux_buffer_params_v1_created(struct ::wl_buffer *)
    {
    }

    void zwp_linux_buffer_params_v1::handle_created(
        void *data,
        struct ::zwp_linux_buffer_params_v1 *object,
        struct ::wl_buffer *buffer)
    {
        Q_UNUSED(object);
        static_cast<zwp_linux_buffer_params_v1 *>(data)->zwp_linux_buffer_params_v1_created(
            buffer);
    }

    void zwp_linux_buffer_params_v1::zwp_linux_buffer_params_v1_failed()
    {
    }

    void zwp_linux_buffer_params_v1::handle_failed(
        void *data,
        struct ::zwp_linux_buffer_params_v1 *object)
    {
        Q_UNUSED(object);
        static_cast<zwp_linux_buffer_params_v1 *>(data)->zwp_linux_buffer_params_v1_failed();
    }

    const struct zwp_linux_buffer_params_v1_listener zwp_linux_buffer_params_v1::m_zwp_linux_buffer_params_v1_listener = {
        zwp_linux_buffer_params_v1::handle_created,
        zwp_linux_buffer_params_v1::handle_failed,
    };

    void zwp_linux_buffer_params_v1::init_listener()
    {
        zwp_linux_buffer_params_v1_add_listener(m_zwp_linux_buffer_params_v1, &m_zwp_linux_buffer_params_v1_listener, this);
    }

    zwp_linux_dmabuf_feedback_v1::zwp_linux_dmabuf_feedback_v1(struct ::wl_registry *registry, uint32_t id, int version)
    {
        init(registry, id, version);
    }

    zwp_linux_dmabuf_feedback_v1::zwp_linux_dmabuf_feedback_v1(struct ::zwp_linux_dmabuf_feedback_v1 *obj)
        : m_zwp_linux_dmabuf_feedback_v1(obj)
    {
        init_listener();
    }

    zwp_linux_dmabuf_feedback_v1::zwp_linux_dmabuf_feedback_v1()
        : m_zwp_linux_dmabuf_feedback_v1(nullptr)
    {
    }

    zwp_linux_dmabuf_feedback_v1::~zwp_linux_dmabuf_feedback_v1()
    {
    }

    void zwp_linux_dmabuf_feedback_v1::init(struct ::wl_registry *registry, uint32_t id, int version)
    {
        m_zwp_linux_dmabuf_feedback_v1 = static_cast<struct ::zwp_linux_dmabuf_feedback_v1 *>(wlRegistryBind(registry, id, &zwp_linux_dmabuf_feedback_v1_interface, version));
        init_listener();
    }

    void zwp_linux_dmabuf_feedback_v1::init(struct ::zwp_linux_dmabuf_feedback_v1 *obj)
    {
        m_zwp_linux_dmabuf_feedback_v1 = obj;
        init_listener();
    }

    zwp_linux_dmabuf_feedback_v1 *zwp_linux_dmabuf_feedback_v1::fromObject(struct ::zwp_linux_dmabuf_feedback_v1 *object)
    {
        if (wl_proxy_get_listener((struct ::wl_proxy *)object) != (void *)&m_zwp_linux_dmabuf_feedback_v1_listener)
            return nullptr;
        return static_cast<zwp_linux_dmabuf_feedback_v1 *>(zwp_linux_dmabuf_feedback_v1_get_user_data(object));
    }

    bool zwp_linux_dmabuf_feedback_v1::isInitialized() const
    {
        return m_zwp_linux_dmabuf_feedback_v1 != nullptr;
    }

    uint32_t zwp_linux_dmabuf_feedback_v1::version() const
    {
        return wl_proxy_get_version(reinterpret_cast<wl_proxy*>(m_zwp_linux_dmabuf_feedback_v1));
    }

    const struct wl_interface *zwp_linux_dmabuf_feedback_v1::interface()
    {
        return &::zwp_linux_dmabuf_feedback_v1_interface;
    }

    void zwp_linux_dmabuf_feedback_v1::destroy()
    {
        ::zwp_linux_dmabuf_feedback_v1_destroy(
            m_zwp_linux_dmabuf_feedback_v1);
        m_zwp_linux_dmabuf_feedback_v1 = nullptr;
    }

    void zwp_linux_dmabuf_feedback_v1::zwp_linux_dmabuf_feedback_v1_done()
    {
    }

    void zwp_linux_dmabuf_feedback_v1::handle_done(
        void *data,
        struct ::zwp_linux_dmabuf_feedback_v1 *object)
    {
        Q_UNUSED(object);
        static_cast<zwp_linux_dmabuf_feedback_v1 *>(data)->zwp_linux_dmabuf_feedback_v1_done();
    }

    void zwp_linux_dmabuf_feedback_v1::zwp_linux_dmabuf_feedback_v1_format_table(int32_t , uint32_t )
    {
    }

    void zwp_linux_dmabuf_feedback_v1::handle_format_table(
        void *data,
        struct ::zwp_linux_dmabuf_feedback_v1 *object,
        int32_t fd,
        uint32_t size)
    {
        Q_UNUSED(object);
        static_cast<zwp_linux_dmabuf_feedback_v1 *>(data)->zwp_linux_dmabuf_feedback_v1_format_table(
            fd,
            size);
    }

    void zwp_linux_dmabuf_feedback_v1::zwp_linux_dmabuf_feedback_v1_main_device(wl_array *)
    {
    }

    void zwp_linux_dmabuf_feedback_v1::handle_main_device(
        void *data,
        struct ::zwp_linux_dmabuf_feedback_v1 *object,
        wl_array *device)
    {
        Q_UNUSED(object);
        static_cast<zwp_linux_dmabuf_feedback_v1 *>(data)->zwp_linux_dmabuf_feedback_v1_main_device(
            device);
    }

    void zwp_linux_dmabuf_feedback_v1::zwp_linux_dmabuf_feedback_v1_tranche_done()
    {
    }

    void zwp_linux_dmabuf_feedback_v1::handle_tranche_done(
        void *data,
        struct ::zwp_linux_dmabuf_feedback_v1 *object)
    {
        Q_UNUSED(object);
        static_cast<zwp_linux_dmabuf_feedback_v1 *>(data)->zwp_linux_dmabuf_feedback_v1_tranche_done();
    }

    void zwp_linux_dmabuf_feedback_v1::zwp_linux_dmabuf_feedback_v1_tranche_target_device(wl_array *)
    {
    }

    void zwp_linux_dmabuf_feedback_v1::handle_tranche_target_device(
        void *data,
        struct ::zwp_linux_dmabuf_feedback_v1 *object,
        wl_array *device)
    {
        Q_UNUSED(object);
        static_cast<zwp_linux_dmabuf_feedback_v1 *>(data)->zwp_linux_dmabuf_feedback_v1_tranche_target_device(
            device);
    }

    void zwp_linux_dmabuf_feedback_v1::zwp_linux_dmabuf_feedback_v1_tranche_formats(wl_array *)
    {
    }

    void zwp_linux_dmabuf_feedback_v1::handle_tranche_formats(
        void *data,
        struct ::zwp_linux_dmabuf_feedback_v1 *object,
        wl_array *indices)
    {
        Q_UNUSED(object);
        static_cast<zwp_linux_dmabuf_feedback_v1 *>(data)->zwp_linux_dmabuf_feedback_v1_tranche_formats(
            indices);
    }

    void zwp_linux_dmabuf_feedback_v1::zwp_linux_dmabuf_feedback_v1_tranche_flags(uint32_t )
    {
    }

    void zwp_linux_dmabuf_feedback_v1::handle_tranche_flags(
        void *data,
        struct ::zwp_linux_dmabuf_feedback_v1 *object,
        uint32_t flags)
    {
        Q_UNUSED(object);
        static_cast<zwp_linux_dmabuf_feedback_v1 *>(data)->zwp_linux_dmabuf_feedback_v1_tranche_flags(
            flags);
    }

    const struct zwp_linux_dmabuf_feedback_v1_listener zwp_linux_dmabuf_feedback_v1::m_zwp_linux_dmabuf_feedback_v1_listener = {
        zwp_linux_dmabuf_feedback_v1::handle_done,
        zwp_linux_dmabuf_feedback_v1::handle_format_table,
        zwp_linux_dmabuf_feedback_v1::handle_main_device,
        zwp_linux_dmabuf_feedback_v1::handle_tranche_done,
        zwp_linux_dmabuf_feedback_v1::handle_tranche_target_device,
        zwp_linux_dmabuf_feedback_v1::handle_tranche_formats,
        zwp_linux_dmabuf_feedback_v1::handle_tranche_flags,
    };

    void zwp_linux_dmabuf_feedback_v1::init_listener()
    {
        zwp_linux_dmabuf_feedback_v1_add_listener(m_zwp_linux_dmabuf_feedback_v1, &m_zwp_linux_dmabuf_feedback_v1_listener, this);
    }
}

QT_WARNING_POP
QT_END_NAMESPACE
